=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-04-23 21:05:33 +0000
+++ drizzled/session.h	2011-04-29 12:39:24 +0000
@@ -1074,7 +1074,7 @@
 
   /* Create a lock in the cache */
   table::Placeholder& table_cache_insert_placeholder(const identifier::Table&);
-  bool lock_table_name_if_not_cached(const identifier::Table &identifier, Table **table);
+  Table* lock_table_name_if_not_cached(const identifier::Table&);
 
   session::TableMessages &getMessageCache();
 

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-04-23 21:05:33 +0000
+++ drizzled/sql_base.cc	2011-04-29 12:39:24 +0000
@@ -775,24 +775,17 @@
   @retval  true   Error occured (OOM)
   @retval  false  Success. 'table' parameter set according to above rules.
 */
-bool Session::lock_table_name_if_not_cached(const identifier::Table &identifier, Table **table)
+Table* Session::lock_table_name_if_not_cached(const identifier::Table &identifier)
 {
   const identifier::Table::Key &key(identifier.getKey());
-
   boost::mutex::scoped_lock scope_lock(table::Cache::mutex()); /* Obtain a name lock even though table is not in cache (like for create table)  */
-
   if (find_ptr(table::getCache(), key))
-  {
-    *table= 0;
-    return false;
-  }
-
-  *table= &table_cache_insert_placeholder(identifier);
-  (*table)->open_placeholder= true;
-  (*table)->setNext(open_tables.open_tables_);
-  open_tables.open_tables_= *table;
-
-  return false; //return void
+    return NULL;
+  Table& table= table_cache_insert_placeholder(identifier);
+  table.open_placeholder= true;
+  table.setNext(open_tables.open_tables_);
+  open_tables.open_tables_= &table;
+  return &table;
 }
 
 /*

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-04-20 22:18:30 +0000
+++ drizzled/sql_table.cc	2011-04-29 12:39:24 +0000
@@ -1476,14 +1476,9 @@
                                  uint32_t select_field_count,
                                  bool is_if_not_exists)
 {
-  Table *name_lock= NULL;
+  Table *name_lock= session->lock_table_name_if_not_cached(identifier);
   bool result;
-
-  if (session->lock_table_name_if_not_cached(identifier, &name_lock))
-  {
-    result= true;
-  }
-  else if (name_lock == NULL)
+  if (name_lock == NULL)
   {
     if (is_if_not_exists)
     {
@@ -2103,19 +2098,7 @@
   }
   else // Standard table which will require locks.
   {
-    Table *name_lock= 0;
-
-    if (session->lock_table_name_if_not_cached(destination_identifier, &name_lock))
-    {
-      if (name_lock)
-      {
-        boost::mutex::scoped_lock lock(table::Cache::mutex()); /* unlink open tables for create table like*/
-        session->unlink_open_table(name_lock);
-      }
-
-      return res;
-    }
-
+    Table *name_lock= session->lock_table_name_if_not_cached(destination_identifier);
     if (not name_lock)
     {
       table_exists= true;

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-04-29 00:19:38 +0000
+++ drizzled/statement/alter_table.cc	2011-05-02 18:32:53 +0000
@@ -841,7 +841,6 @@
   {
     if (original_table_identifier.isTmp())
     {
-
       if (session.open_tables.find_temporary_table(new_table_identifier))
       {
         my_error(ER_TABLE_EXISTS_ERROR, new_table_identifier);
@@ -850,11 +849,7 @@
     }
     else
     {
-      if (session.lock_table_name_if_not_cached(new_table_identifier, &name_lock))
-      {
-        return false;
-      }
-
+      name_lock= session.lock_table_name_if_not_cached(new_table_identifier);
       if (not name_lock)
       {
         my_error(ER_TABLE_EXISTS_ERROR, new_table_identifier);

